**diff** - Compare profiles
=================================

Usage
------

.. code::

    e4s-cl profile diff <NAME> <OTHER NAME>

Description
-------------

.. automodule:: e4s_cl.cli.commands.profile.diff
